@@ -8,7 +8,7 @@ st_as_sf.map = function(x, ...) {
 
 	ID0 = vapply(strsplit(x$names, ":"), function(y) y[1], "")
 	m.sp = maptools::map2SpatialPolygons(x, IDs = ID0, 
-		proj4string = sp::CRS("+init=epsg:4326"))
+		proj4string = sp::CRS("+proj=longlat +datum=WGS84 +no_defs"))
 	m = st_as_sf(m.sp)
 	m$ID = vapply(m.sp@polygons, function(x) slot(x, "ID"), "")
 	m
