@@ -238,11 +238,16 @@ as_Spatial = function(from, cast = TRUE, IDs = paste0("ID", 1:length(from))) {
 	if (zm %in% c("XYM", "XYZM"))
 		stop("geometries containing M not supported by sp\n",
 			 'use `st_zm(..., what = "M")`')
-	StopZ = function(zm) { if (zm %in% c("XYZ", "XYZM"))
-		stop("sp supports Z dimension only for POINT and MULTIPOINT.\n",
-			 'use `st_zm(...)` to coerce to XY dimensions') }
+	if (any(st_is_empty(from)))
+		stop("empty geometries are not supported by sp classes: conversion failed")
+	StopZ = function(zm) { 
+		if (zm == "XYZ")
+			stop("sp supports Z dimension only for POINT and MULTIPOINT.\n",
+				 'use `st_zm(...)` to coerce to XY dimensions')
+	}
 	switch(class(from)[1],
 		"sfc_POINT" = sfc2SpatialPoints(from),
+#		"sfc_POINT" = sfc2SpatialPoints(from, IDs),
 		"sfc_MULTIPOINT" = sfc2SpatialMultiPoints(from),
 		"sfc_LINESTRING" = , "sfc_MULTILINESTRING" = { StopZ(zm); sfc2SpatialLines(from, IDs) },
 		"sfc_POLYGON" = , "sfc_MULTIPOLYGON" = { StopZ(zm); sfc2SpatialPolygons(from, IDs) },
@@ -250,9 +255,12 @@ as_Spatial = function(from, cast = TRUE, IDs = paste0("ID", 1:length(from))) {
 	)
 }
 
-sfc2SpatialPoints = function(from) {
+sfc2SpatialPoints = function(from, IDs) {
 	if (!requireNamespace("sp", quietly = TRUE))
 		stop("package sp required, please install it first")
+#	cc = do.call(rbind, from)
+#	row.names(cc) = IDs
+#	sp::SpatialPoints(cc, proj4string = sp::CRS(attr(from, "crs")$proj4string))
 	sp::SpatialPoints(do.call(rbind, from), proj4string = sp::CRS(attr(from, "crs")$proj4string))
 }
 
